@@ -24,7 +24,6 @@
 #include "appchooserbutton.h"
 #include "appchooserdialog.h"
 #include "appchooserwidget.h"
-#include "application.h"
 #include "arrow.h"
 #include "aspectframe.h"
 #include "assistant.h"
@@ -64,8 +63,8 @@
 #include "drawingarea.h"
 #include "editable.h"
 #include "entry.h"
-#include "entrycompletion.h"
 #include "entrybuffer.h"
+#include "entrycompletion.h"
 #include "enums.h"
 #include "eventbox.h"
 #include "expander.h"
@@ -107,13 +106,27 @@
 #include "offscreenwindow.h"
 #include "orientable.h"
 #include "pagesetup.h"
+#ifndef G_OS_WIN32
+#include "pagesetupunixdialog.h"
+#endif //G_OS_WIN32
 #include "paned.h"
 #include "papersize.h"
+#ifndef G_OS_WIN32
 #include "plug.h"
+#endif //G_OS_WIN32
 #include "printcontext.h"
+#ifndef G_OS_WIN32
+#include "printer.h"
+#endif //G_OS_WIN32
+#ifndef G_OS_WIN32
+#include "printjob.h"
+#endif //G_OS_WIN32
 #include "printoperation.h"
 #include "printoperationpreview.h"
 #include "printsettings.h"
+#ifndef G_OS_WIN32
+#include "printunixdialog.h"
+#endif //G_OS_WIN32
 #include "progressbar.h"
 #include "radioaction.h"
 #include "radiobutton.h"
@@ -140,7 +153,9 @@
 #include "separatortoolitem.h"
 #include "settings.h"
 #include "sizegroup.h"
+#ifndef G_OS_WIN32
 #include "socket.h"
+#endif //G_OS_WIN32
 #include "spinbutton.h"
 #include "spinner.h"
 #include "statusbar.h"
@@ -189,10 +204,6 @@
 #include "widget.h"
 #include "widgetpath.h"
 #include "window.h"
-#include "pagesetupunixdialog.h"
-#include "printer.h"
-#include "printjob.h"
-#include "printunixdialog.h"
 
 extern "C"
 {
@@ -209,7 +220,6 @@ GType gtk_alignment_get_type(void);
 GType gtk_app_chooser_button_get_type(void);
 GType gtk_app_chooser_dialog_get_type(void);
 GType gtk_app_chooser_widget_get_type(void);
-GType gtk_application_get_type(void);
 GType gtk_arrow_get_type(void);
 GType gtk_aspect_frame_get_type(void);
 GType gtk_assistant_get_type(void);
@@ -396,7 +406,6 @@ namespace Gtk {  class Alignment_Class { public: static Glib::ObjectBase* wrap_n
 namespace Gtk {  class AppChooserButton_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class AppChooserDialog_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class AppChooserWidget_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
-namespace Gtk {  class Application_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class Arrow_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class AspectFrame_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gtk {  class Assistant_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -583,7 +592,6 @@ void wrap_init()
   Glib::wrap_register(gtk_app_chooser_button_get_type(), &Gtk::AppChooserButton_Class::wrap_new);
   Glib::wrap_register(gtk_app_chooser_dialog_get_type(), &Gtk::AppChooserDialog_Class::wrap_new);
   Glib::wrap_register(gtk_app_chooser_widget_get_type(), &Gtk::AppChooserWidget_Class::wrap_new);
-  Glib::wrap_register(gtk_application_get_type(), &Gtk::Application_Class::wrap_new);
   Glib::wrap_register(gtk_arrow_get_type(), &Gtk::Arrow_Class::wrap_new);
   Glib::wrap_register(gtk_aspect_frame_get_type(), &Gtk::AspectFrame_Class::wrap_new);
   Glib::wrap_register(gtk_assistant_get_type(), &Gtk::Assistant_Class::wrap_new);
@@ -758,7 +766,6 @@ void wrap_init()
   Gtk::AppChooserButton::get_type();
   Gtk::AppChooserDialog::get_type();
   Gtk::AppChooserWidget::get_type();
-  Gtk::Application::get_type();
   Gtk::Arrow::get_type();
   Gtk::AspectFrame::get_type();
   Gtk::Assistant::get_type();
